<template>
  <!--系统集成的系统任务页面-->
  <basic-container>
    <avue-crud :option="option"
               :table-loading="loading"
               :data="data"
               :page.sync="page"
               :permission="permissionList"
               ref="crud"
               @search-change="searchChange"
               @search-reset="searchReset"
               @selection-change="selectionChange"
               @current-change="currentChange"
               @size-change="sizeChange"
               @refresh-change="refreshChange"
               @on-load="onLoad">
      <template slot="menuLeft">
        <el-button type="primary"
                   size="small"
                   plain
                   icon="el-icon-refresh-right"
                   @click="handleSend">手动推送
        </el-button>
      </template>
    </avue-crud>
  </basic-container>
</template>

<script>
import {getList,sendData} from "@/api/docking/task";
import {validatenull} from "@/util/validate";
import {mapGetters} from "vuex";
import {remove} from "@/api/code/codeSynonym";

export default {
  name: "task",
  data(){
    return {
      loading: false,
      query: {},
      selectionList: [],
      page: {
        pageSize: 20,
        currentPage: 1,
        total: 0
      },
      data:[],
      option: {
        calcHeight: 30,
        tip: false,
        searchShow: false,
        searchMenuSpan: 6,
        border: true,
        index: true,
        viewBtn: true,
        selection: true,
        dialogClickModal: false,
        menu:false,
        column: [
          {
            label: "数据编码",
            prop: "id",
            search: true,
            sortable:true,
            width:150
          },
          {
            label: "图号",
            prop: "uniquecode",
            search: true,
            sortable:true,
            width:150
          },
          {
            label: '分类id',
            prop: 'classifyid',
            search: true,
            sortable:true,
            width: 250
          },
          {
            label: '分类名称',
            prop: 'classifyname',
            search: true,
            sortable:true
          },
          {
            label: '系统编号',
            prop: 'systemcode',
            search: true,
            sortable:true,
            width: 150
          },
          {
            label: '系统名称',
            prop: 'systemname',
            search: true,
            sortable:true,
            width: 150
          },
          {
            label: '数据情况',
            prop: 'sendtype',
            sortable:true,
            width: 100
          },
          {
            label: '是否推送成功',
            prop: 'sendflag',
            search: true,
            sortable:true,
            width: 120,
            html:true,
            align:'center',
            type:'select',
            dicData: [{key:'true',value:'是'},{key:'false',value:'否'}],
            props: {
              label: "value",
              value: "key"
            },
            formatter : function (row, column) {
              return row.sendflag == 'true' || row.sendflag == '1' ? '<i class="el-icon-check"></i>' : '<i class="el-icon-close"></i>'
            }
          },
          {
            label: '任务创建时间',
            prop: 'createTime',
            sortable:true,
            width: 150
          },
          {
            label: '最后推送时间',
            prop: 'lastModifyTime',
            sortable:true,
            width: 150
          }
        ]
      }
    }
  },
  computed:{
    ...mapGetters([ "permission"]),
    permissionList() {
      return {
        addBtn: false,
        viewBtn: false,
        delBtn: false,
        editBtn: false
      };
    },
    oids() {
      let oids = [];
      this.selectionList.forEach(ele => {
        oids.push(ele.oid);
      });
      return oids.join(",");
    }
  },
  methods: {
    searchReset() {
      this.query = {};
      this.onLoad(this.page);
    },
    searchChange(params, done) {
      this.query = params;
      this.page.currentPage = 1;
      this.onLoad(this.page);
      done();
    },
    selectionChange(list) {
      this.selectionList = list;
    },
    selectionClear() {
      this.selectionList = [];
      this.$refs.crud.toggleSelection();
    },
    currentChange(currentPage) {
      this.page.currentPage = currentPage;
    },
    sizeChange(pageSize) {
      this.page.pageSize = pageSize;
    },
    refreshChange() {
      this.onLoad(this.page);
    },
    onLoad(page, params = {}) {
      this.loading = true;
      var query = {}
      if (this.query) {
        for (var key in this.query) {
          query['conditionMap["' + key + '"]'] = this.query[key];
        }
      }
      getList(page.currentPage, page.pageSize, Object.assign(params, this.params, query, this.query)).then(res => {
        const data = res.data.data;
        this.page.total = data.total;
        this.data = data.records;
        this.loading = false;
        this.selectionClear();
      }).catch(error => {
        this.$message.error(error);
        this.loading = false;
      });
    },
    handleSend() {
      let data = new FormData();
      if (this.selectionList.length === 0) {
        this.$message.warning("请选择至少一条数据");
        return;
      }
      data.append('oid', this.oids)
      this.$confirm("是否推送数据?", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return sendData(data)
        })
        .then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
        }).catch(error => {
        this.$message.error(error);
      });
    }
  }

}
</script>

<style scoped>

</style>
